<?php

declare(strict_types=1);

namespace app\controllers;

use yii;
use yii\web\Controller;
use app\models\Account;
use yii\web\Response;

class VerifyController extends Controller
{
    public function actionIndex(string $vrfy = null): string|Response
    {
        if (isset($vrfy)) {
            // Подтверждение регистрации

            if (Account::verification($vrfy, auth: true)) {
                // Успешно подтверждена регистрация

                return $this->redirect('/');
            }

            return ErrorController::throw('Ошибка подтверждения регистрации', 'Код подтверждения не совпадает с тем, что мы отправили вам на почту, либо регистрация уже была подтверждена. Свяжитесь с администрацией');
        } else {
            // Простой запрос

            return $this->render('/account/verify');
        }
    }

    /**
     * Отправить запрос на активацию
     *
     * @return string
     */
    public function actionSend(): string|array
    {
        yii::$app->user->identity->verifyRegenerate();

        yii::$app->user->identity->sendMailVerify();

        if (yii::$app->request->isPost) {
            // POST-запрос

            yii::$app->response->format = Response::FORMAT_JSON;

            return [
                'main' => $this->renderPartial('/account/verify'),
                'title' => 'Корзина',
                '_csrf' => yii::$app->request->getCsrfToken()
            ];
        } else {
            // Подразумевается как GET-запрос

            return $this->render('/account/verify');
        }
    }
}
